# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.0.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASLimsworkflow(str, Enum):
    """
    Enum class for LASLimsworkflow
    """

    """
    allowed enum values
    """
    CHARACTERIZATION = 'Characterization'
    MGT_ANTEROGRADE_PROJECTIO = 'MGT Anterograde Projection Mapping'
    N_2P_SERIAL_IMAGING = '2p serial Imaging'
    SCREENING = 'Screening'
    T5032_ANTEROGRADE_TARGET = 'T503.2 Anterograde Target-Defined'
    T5033_ALZHEIMERS_PLAQUE = 'T503.3 Alzheimer\'s Plaque'
    T5033_CONTROL = 'T503.3 control'
    T503_ANTEROGRADE_CREDEFIN = 'T503 anterograde Cre-defined SypEGFP'
    T6011_RETINA = 'T601.1 Retina'
    T6012A_RETROGRADE_CAV2_CR = 'T601.2a Retrograde CAV2-Cre;Ai75'
    T6012B_RETROGRADE_RABIESG = 'T601.2b Retrograde Rabies-GFP'
    T6012C_RETROGRADE_FLUOROG = 'T601.2c Retrograde Fluorogold'
    T6013A_ANTEROGRADE_CRE_DE = 'T601.3a Anterograde Cre-Defined EGFP'
    T6013B_ANTEROGRADE_CRE_DE = 'T601.3b Anterograde Cre-Deflned SypEGFP'
    T6014_ANTEROGRADE_TARGET = 'T601.4 Anterograde Target Defined'
    T6015_TRANSSYNAPTIC = 'T601.5 trans-synaptic'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASLimsworkflow from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.0.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_sharepoint_service_client.models.nsb2023_edema_swelling import NSB2023EdemaSwelling

class TestNSB2023EdemaSwelling(unittest.TestCase):
    """NSB2023EdemaSwelling unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNSB2023EdemaSwelling(self):
        """Test NSB2023EdemaSwelling"""
        # inst = NSB2023EdemaSwelling()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.0.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASProjectid(str, Enum):
    """
    Enum class for LASProjectid
    """

    """
    allowed enum values
    """
    AAV_PRODUCTION_1028800410 = 'AAV production 102-88-004-10'
    N_1010300110_COSTA_PGA_LA = '101-03-001-10 Costa PGA Lab Research (Direct)'
    N_1020100710_CTY_M_FISH = '102-01-007-10 CTY mFISH'
    N_1020100910_CTY_MORPHOLO = '102-01-009-10 CTY Morphology'
    N_1020101110_CTY_CONNECTO = '102-01-011-10 CTY Connectome EM'
    N_1020101210_CTY_CONNECTO = '102-01-012-10 CTY Connectome Meso'
    N_1020101610_CTY_TAXONOMY = '102-01-016-10 CTY Taxonomy'
    N_1020102720_CTY_BRAIN_AX = '102-01-027-20 CTY BRAIN Axonal Connectomics'
    N_1020102920_CTY_BRAIN_CE = '102-01-029-20 CTY BRAIN Cell-type Specific Enhancer Viruses'
    N_1020103120_W4_CTY_EU_HO = '102-01-031-20 W4 - CTY EU Horizon 2020 BRAINTIME'
    N_1020103120_W5_CTY_EU_HO = '102-01-031-20 W5 - CTY EU Horizon 2020 BRAINTIME'
    N_1020103220_CTY_MOUSE_AG = '102-01-032-20 CTY Mouse Aging'
    N_1020103620_CTY_DISSEMIN = '102-01-036-20 CTY Dissemination of 3-Photon Imaging'
    N_1020104020_CTY_BRAIN_UG = '102-01-040-20 CTY BRAIN UG3/UH3 Genetic Viral Tools'
    N_1020104320_CTY_OPTICAL = '102-01-043-20 CTY Optical interrogation'
    N_1020104410_CTY_GENOMICS = '102-01-044-10 – CTY Genomics'
    N_1020104510_CTY_IVSCC = '102-01-045-10 – CTY IVSCC'
    N_1020104620_CTY_WEILL_NE = '102-01-046-20 - CTY Weill Neuronal Heterogeneity'
    N_1020104810_CTY_BARCODED = '102-01-048-10 CTY Barcoded Connectomics'
    N_1020104920_CTY_OPIOID_T = '102-01-049-20 - CTY Opioid Transcriptomics'
    N_1020105520_CTY_EM_MOTOR = '102-01-055-20 CTY EM Motor Cortex'
    N_1020105720_CTY_BRAIN_BG = '102-01-057-20 CTY BRAIN BG AAV Toolbox'
    N_1020105920_CTY_SCORCH = '102-01-059-20 CTY SCORCH'
    N_1020106020_CTY_BRAIN_DR = '102-01-060-20 CTY Brain Drain'
    N_1020106120_CTY_BICAN_HU = '102-01-061-20 CTY BICAN Human and NHP Atlas'
    N_1020106220_CTY_BICAN_MO = '102-01-062-20 CTY BICAN Mouse Developmental Atlas'
    N_1020106410_CTY_GENETIC = '102-01-064-10 CTY Genetic Tools'
    N_1020106620_CTY_CONNECTS = '102-01-066-20 CTY CONNECTS HIVE'
    N_1020106820_CTY_CONNECTS = '102-01-068-20 CTY CONNECTS Patchlink'
    N_1020106920_PRE_SPEND = '102-01-069-20 Pre-Spend'
    N_1020107020_CTY_CONNECTS = '102-01-070-20 CTY CONNECTS MouseConnects'
    N_1020199910_CTY_PROGRAM = '102-01-999-10 CTY Program Admin'
    N_1020200410_BTV_VISUAL_B = '102-02-004-10 BTV Visual Behavior'
    N_1020201220_BTV_BRAIN_VI = '102-02-012-20 BTV BRAIN Viral Strategies'
    N_1020201620_MSP_BRAIN_MO = '102-02-016-20 MSP BRAIN Models and methods for Ca Imaging'
    N_1020201720_BTV_BRAIN_NE = '102-02-017-20 BTV BRAIN Neuropixels ULTRA'
    N_1020400410_OTH_MERITORI = '102-04-004-10 OTH Meritorious Scholar Directed Research'
    N_1020400620_OTH_MEASURIN = '102-04-006-20 OTH Measuring Consciousness Ph2 (TBD)'
    N_1020400710_APLD_TARGETE = '102-04-007-10 APLD Targeted CNS Gene Therapy'
    N_1020401010_CTY_SR_SLC6 = '102-04-010-10 CTY SR: SLC6A1'
    N_1020401110_CTY_SR_SYNGA = '102-04-011-10 CTY SR: SYNGAP1'
    N_1020401210_CTY_SR_FRIED = '102-04-012-10 : CTY SR: Friedreich Ataxia'
    N_1020401410_CTY_PARKINSO = '102-04-014-10 CTY Parkinsons Disease'
    N_1028800310_ANIMAL_CARE = '102-88-003-10 Animal Care Team'
    N_1028800510_TRANSGENIC_C = '102-88-005-10 Transgenic Colony Management'
    N_1028800810_LAB_ANIMAL_S = '102-88-008-10 Lab Animal Services'
    N_1060100110_IMMUNOLOGY_D = '106-01-001-10 Immunology (Direct)'
    N_1210101620_MSP_BRAIN_OP = '121-01-016-20 MSP BRAIN OpenScope'
    N_1210101820_MSP_EPHAPTIC = '121-01-018-20 MSP Ephaptic Cell Typ'
    N_1210102320_MSP_TEMPLETO = '121-01-023-20 MSP Templeton - Testing Theories of Consciousness'
    N_1210102520_MSP_U01_BRID = '121-01-025-20 MSP U01 Bridging Function, Connectivity, & Transcriptomics'
    N_1210102620_MSP_TEMPLETO = '121-01-026-20 MSP Templeton Measuring Distinct Conscious State'
    N_1220100110_AIND_SCIENTI = '122-01-001-10 AIND Scientific Activities'
    N_1220100220_MOLECULAR_CO = '122-01-002-20 Molecular Core'
    N_1220100220_PROJECT_1 = '122-01-002-20 Project 1'
    N_1220100220_PROJECT_2 = '122-01-002-20 Project 2'
    N_1220100220_PROJECT_4 = '122-01-002-20 Project 4'
    N_1220100420_AIND_BRAINST = '122-01-004-20 AIND Brainstem RF1'
    N_1220101020_AIND_POO_SIM = '122-01-010-20 - AIND Poo Simons BTI'
    N_1220101120_AIND_COHEN_J = '122-01-011-20 - AIND Cohen JHU R01 Transferred Subaward'
    N_1220101220_AIND_RF1_FUN = '122-01-012-20 - AIND RF1 Functions of locus coeruleus'
    N_1220101310_MSP_SCIENTIF = '122-01-013-10 MSP Scientific Activities'
    N_1220101420_AIND_SIEGLE = '122-01-014-20 - AIND Siegle U01 NPOpto'
    N_1220101920_AIND_CZI_COL = '122-01-019-20 AIND CZI Collaborative Pairs'
    N_1220102020_AIBS_COHEN_B = '122-01-020-20 AIBS Cohen BICAN R01'
    N_1220102020_AIND_COHEN_B = '122-01-020-20 AIND Cohen BICAN R01'
    N_1229999910_NEURAL_DYNAM = '122-99-999-10 Neural Dynamics Admin (Direct)'
    N_1250100110_SEA_HUB_SCIE = '125-01-001-10 - SeaHub Scientific Activities (Direct)'
    RD_1028800410 = 'R&D 102-88-004-10'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASProjectid from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.0.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Burr5IntendedMeasurementIsosbestic(str, Enum):
    """
    Enum class for Burr 5 intended measurement isosbestic.
    """

    """
    allowed enum values
    """
    N_A = 'N/A'
    DOPAMINE = 'dopamine'
    SEROTONIN = 'serotonin'
    NOREPINEPHRINE = 'norepinephrine'
    ACETYLCHOLINE = 'acetylcholine'
    HISTAMINE = 'histamine'
    GLUTAMATE = 'glutamate'
    GABA = 'GABA'
    CALCIUM = 'calcium'
    VOLTAGE = 'voltage'
    CONTROL = 'control'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Burr5IntendedMeasurementIsosbestic from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.0.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Lightcycle(str, Enum):
    """
    Enum class for NSB2023LightCycle.
    """

    """
    allowed enum values
    """
    STANDARD__LIGHT__CYCLE_6A = 'Standard Light Cycle (6am to 8pm light)'
    REVERSE__LIGHT__CYCLE_9PM = 'Reverse Light Cycle (9pm to 9am light)'
    N_249_ABSL2 = '249 (ABSL2)'
    REVERSE_9PM_TO_9AM = 'Reverse (9pm to 9am)'
    STANDARD_6AM_TO_8PM = 'Standard (6am to 8pm)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Lightcycle from a JSON string"""
        return cls(json.loads(json_str))


